"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Player = void 0;
const debug_1 = __importDefault(require("debug"));
const node_mpv_1 = __importDefault(require("node-mpv"));
class Player {
    constructor() {
        this.mpv = new node_mpv_1.default();
        this.debug = debug_1.default("player");
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            this.debug("Starting mpv...");
            yield this.mpv.start();
        });
    }
    play(url) {
        return __awaiter(this, void 0, void 0, function* () {
            this.debug(`Playing ${url}...`);
            yield this.mpv.mute(false);
            yield this.mpv.loopPlaylist('inf');
            yield this.mpv.load(url, 'replace');
        });
    }
    stop() {
        return __awaiter(this, void 0, void 0, function* () {
            this.debug("Stop");
            yield this.mpv.mute(true);
        });
    }
    status() {
        return __awaiter(this, void 0, void 0, function* () {
            const [muted, paused, running, seekable] = yield Promise.all([
                this.mpv.isMuted(),
                this.mpv.isPaused(),
                this.mpv.isRunning(),
                this.mpv.isSeekable()
            ]);
            return { muted, paused, running, seekable };
        });
    }
}
exports.Player = Player;
